@@ -1,34 +1,5 @@
-/*
- * Copyright 2015-2018, Intel Corporation
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *      * Redistributions of source code must retain the above copyright
- *       notice, this list of conditions and the following disclaimer.
- *
- *      * Redistributions in binary form must reproduce the above copyright
- *       notice, this list of conditions and the following disclaimer in
- *       the documentation and/or other materials provided with the
- *       distribution.
- *
- *      * Neither the name of the copyright holder nor the names of its
- *        contributors may be used to endorse or promote products derived
- *        from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+// SPDX-License-Identifier: BSD-3-Clause
+/* Copyright 2015-2020, Intel Corporation */
 
 /*
  * pmemobj_tx.cpp -- pmemobj_tx_alloc(), pmemobj_tx_free(),
@@ -43,7 +14,9 @@
 #include <unistd.h>
 
 #include "benchmark.hpp"
+#include "file.h"
 #include "libpmemobj.h"
+#include "poolset_util.hpp"
 
 #define LAYOUT_NAME "benchmark"
 #define FACTOR 1.2f
@@ -180,30 +153,30 @@ struct obj_tx_args {
 	unsigned nested;    /* number of nested transactions */
 	unsigned min_size;  /* minimum allocation size */
 	unsigned min_rsize; /* minimum reallocation size */
-	unsigned rsize;     /* reallocation size */
+	unsigned rsize;	    /* reallocation size */
 	bool change_type;   /* change type number in reallocation */
 	size_t obj_size;    /* size of each allocated object */
-	size_t n_ops;       /* number of operations */
-	int parse_mode;     /* type of parsing function */
+	size_t n_ops;	    /* number of operations */
+	int parse_mode;	    /* type of parsing function */
 };
 
 /*
  * obj_tx_bench -- stores variables used in benchmark, passed within functions.
  */
 static struct obj_tx_bench {
-	PMEMobjpool *pop;	     /* handle to persistent pool */
+	PMEMobjpool *pop;	      /* handle to persistent pool */
 	struct obj_tx_args *obj_args; /* pointer to benchmark arguments */
-	size_t *random_types;	 /* array to store random type numbers */
-	size_t *sizes;      /* array to store size of each allocation */
+	size_t *random_types;	      /* array to store random type numbers */
+	size_t *sizes;	    /* array to store size of each allocation */
 	size_t *resizes;    /* array to store size of each reallocation */
-	size_t n_objs;      /* number of objects to allocate */
-	int type_mode;      /* type number mode */
-	int op_mode;	/* type of operation */
-	int lib_mode;       /* type of operation used in initialization */
-	int lib_op;	 /* type of main operation */
+	size_t n_objs;	    /* number of objects to allocate */
+	int type_mode;	    /* type number mode */
+	int op_mode;	    /* type of operation */
+	int lib_mode;	    /* type of operation used in initialization */
+	int lib_op;	    /* type of main operation */
 	int lib_op_free;    /* type of main operation */
 	int nesting_mode;   /* type of nesting in main operation */
-	fn_num_t n_oid;     /* returns object's number in array */
+	fn_num_t n_oid;	    /* returns object's number in array */
 	fn_os_off_t fn_off; /* returns offset for proper operation */
 
 	/*
@@ -255,9 +228,9 @@ static int
 alloc_dram(struct obj_tx_bench *obj_bench, struct worker_info *worker,
 	   size_t idx)
 {
-	struct obj_tx_worker *obj_worker = (struct obj_tx_worker *)worker->priv;
+	auto *obj_worker = (struct obj_tx_worker *)worker->priv;
 	obj_worker->items[idx] = (char *)malloc(obj_bench->sizes[idx]);
-	if (obj_worker->items[idx] == NULL) {
+	if (obj_worker->items[idx] == nullptr) {
 		perror("malloc");
 		return -1;
 	}
@@ -272,9 +245,10 @@ alloc_pmem(struct obj_tx_bench *obj_bench, struct worker_info *worker,
 	   size_t idx)
 {
 	size_t type_num = obj_bench->fn_type_num(obj_bench, worker->index, idx);
-	struct obj_tx_worker *obj_worker = (struct obj_tx_worker *)worker->priv;
+	auto *obj_worker = (struct obj_tx_worker *)worker->priv;
 	if (pmemobj_alloc(obj_bench->pop, &obj_worker->oids[idx].oid,
-			  obj_bench->sizes[idx], type_num, NULL, NULL) != 0) {
+			  obj_bench->sizes[idx], type_num, nullptr,
+			  nullptr) != 0) {
 		perror("pmemobj_alloc");
 		return -1;
 	}
@@ -288,7 +262,7 @@ static int
 alloc_tx(struct obj_tx_bench *obj_bench, struct worker_info *worker, size_t idx)
 {
 	size_t type_num = obj_bench->fn_type_num(obj_bench, worker->index, idx);
-	struct obj_tx_worker *obj_worker = (struct obj_tx_worker *)worker->priv;
+	auto *obj_worker = (struct obj_tx_worker *)worker->priv;
 	obj_worker->oids[idx].oid = pmemobj_tx_xalloc(
 		obj_bench->sizes[idx], type_num, POBJ_XALLOC_NO_FLUSH);
 	if (OID_IS_NULL(obj_worker->oids[idx].oid)) {
@@ -305,7 +279,7 @@ static int
 free_dram(struct obj_tx_bench *obj_bench, struct worker_info *worker,
 	  size_t idx)
 {
-	struct obj_tx_worker *obj_worker = (struct obj_tx_worker *)worker->priv;
+	auto *obj_worker = (struct obj_tx_worker *)worker->priv;
 	free(obj_worker->items[idx]);
 	return 0;
 }
@@ -317,7 +291,7 @@ static int
 free_pmem(struct obj_tx_bench *obj_bench, struct worker_info *worker,
 	  size_t idx)
 {
-	struct obj_tx_worker *obj_worker = (struct obj_tx_worker *)worker->priv;
+	auto *obj_worker = (struct obj_tx_worker *)worker->priv;
 	POBJ_FREE(&obj_worker->oids[idx]);
 	return 0;
 }
@@ -328,7 +302,7 @@ free_pmem(struct obj_tx_bench *obj_bench, struct worker_info *worker,
 static int
 free_tx(struct obj_tx_bench *obj_bench, struct worker_info *worker, size_t idx)
 {
-	struct obj_tx_worker *obj_worker = (struct obj_tx_worker *)worker->priv;
+	auto *obj_worker = (struct obj_tx_worker *)worker->priv;
 	TX_FREE(obj_worker->oids[idx]);
 	return 0;
 }
@@ -350,10 +324,10 @@ static int
 realloc_dram(struct obj_tx_bench *obj_bench, struct worker_info *worker,
 	     size_t idx)
 {
-	struct obj_tx_worker *obj_worker = (struct obj_tx_worker *)worker->priv;
-	char *tmp = (char *)realloc(obj_worker->items[idx],
+	auto *obj_worker = (struct obj_tx_worker *)worker->priv;
+	auto *tmp = (char *)realloc(obj_worker->items[idx],
 				    obj_bench->resizes[idx]);
-	if (tmp == NULL) {
+	if (tmp == nullptr) {
 		perror("realloc");
 		return -1;
 	}
@@ -368,7 +342,7 @@ static int
 realloc_pmem(struct obj_tx_bench *obj_bench, struct worker_info *worker,
 	     size_t idx)
 {
-	struct obj_tx_worker *obj_worker = (struct obj_tx_worker *)worker->priv;
+	auto *obj_worker = (struct obj_tx_worker *)worker->priv;
 	size_t type_num = obj_bench->fn_type_num(obj_bench, worker->index, idx);
 	if (obj_bench->obj_args->change_type)
 		type_num++;
@@ -387,16 +361,28 @@ static int
 realloc_tx(struct obj_tx_bench *obj_bench, struct worker_info *worker,
 	   size_t idx)
 {
-	struct obj_tx_worker *obj_worker = (struct obj_tx_worker *)worker->priv;
+	auto *obj_worker = (struct obj_tx_worker *)worker->priv;
 	size_t type_num = obj_bench->fn_type_num(obj_bench, worker->index, idx);
 	if (obj_bench->obj_args->change_type)
 		type_num++;
-	obj_worker->oids[idx].oid = pmemobj_tx_realloc(
-		obj_worker->oids[idx].oid, obj_bench->sizes[idx], type_num);
-	if (OID_IS_NULL(obj_worker->oids[idx].oid)) {
+	PMEMoid oid = pmemobj_tx_realloc(obj_worker->oids[idx].oid,
+					 obj_bench->sizes[idx], type_num);
+	if (OID_IS_NULL(oid)) {
 		perror("pmemobj_tx_realloc");
 		return -1;
 	}
+
+	/*
+	 * If OP_MODE_ABORT is set, this TX will get aborted, meaning that the
+	 * object allocated as part of the outer transaction will be freed once
+	 * this operation finishes.
+	 * To avoid a potential use-after-free, we either have to snapshot the
+	 * oid pointer or skip this assignment when we know it will abort.
+	 * For performance reason, this code does the latter.
+	 */
+	if (obj_bench->op_mode != OP_MODE_ABORT)
+		obj_worker->oids[idx].oid = oid;
+
 	return 0;
 }
 
@@ -408,7 +394,7 @@ add_range_nested_tx(struct obj_tx_bench *obj_bench, struct worker_info *worker,
 		    size_t idx)
 {
 	int ret = 0;
-	struct obj_tx_worker *obj_worker = (struct obj_tx_worker *)worker->priv;
+	auto *obj_worker = (struct obj_tx_worker *)worker->priv;
 	TX_BEGIN(obj_bench->pop)
 	{
 		if (obj_bench->obj_args->n_ops != obj_worker->tx_level) {
@@ -439,7 +425,7 @@ add_range_tx(struct obj_tx_bench *obj_bench, struct worker_info *worker,
 {
 	int ret = 0;
 	size_t i = 0;
-	struct obj_tx_worker *obj_worker = (struct obj_tx_worker *)worker->priv;
+	auto *obj_worker = (struct obj_tx_worker *)worker->priv;
 	TX_BEGIN(obj_bench->pop)
 	{
 		for (i = 0; i < obj_bench->obj_args->n_ops; i++) {
@@ -467,7 +453,7 @@ obj_op_sim(struct obj_tx_bench *obj_bench, struct worker_info *worker,
 	   size_t idx)
 {
 	int ret = 0;
-	struct obj_tx_worker *obj_worker = (struct obj_tx_worker *)worker->priv;
+	auto *obj_worker = (struct obj_tx_worker *)worker->priv;
 	if (obj_worker->max_level == obj_worker->tx_level) {
 		ret = obj_bench->fn_op[obj_bench->lib_op](obj_bench, worker,
 							  idx);
@@ -486,7 +472,7 @@ obj_op_tx(struct obj_tx_bench *obj_bench, struct worker_info *worker,
 	  size_t idx)
 {
 	volatile int ret = 0;
-	struct obj_tx_worker *obj_worker = (struct obj_tx_worker *)worker->priv;
+	auto *obj_worker = (struct obj_tx_worker *)worker->priv;
 	TX_BEGIN(obj_bench->pop)
 	{
 		if (obj_worker->max_level == obj_worker->tx_level) {
@@ -630,7 +616,7 @@ parse_lib_mode(const char *arg)
 }
 
 static fn_type_num_t type_num_fn[] = {type_mode_one, type_mode_per_thread,
-				      type_mode_rand, NULL};
+				      type_mode_rand, nullptr};
 
 /*
  * one_num -- returns always the same number.
@@ -683,10 +669,10 @@ static size_t *
 rand_values(size_t min, size_t max, size_t n_ops)
 {
 	size_t size = max - min;
-	size_t *sizes = (size_t *)calloc(n_ops, sizeof(size_t));
-	if (sizes == NULL) {
+	auto *sizes = (size_t *)calloc(n_ops, sizeof(size_t));
+	if (sizes == nullptr) {
 		perror("calloc");
-		return NULL;
+		return nullptr;
 	}
 	for (size_t i = 0; i < n_ops; i++)
 		sizes[i] = max;
@@ -694,7 +680,7 @@ rand_values(size_t min, size_t max, size_t n_ops)
 		if (min > max) {
 			fprintf(stderr, "Invalid size\n");
 			free(sizes);
-			return NULL;
+			return nullptr;
 		}
 		for (size_t i = 0; i < n_ops; i++)
 			sizes[i] = (rand() % size) + min;
@@ -708,10 +694,8 @@ rand_values(size_t min, size_t max, size_t n_ops)
 static int
 obj_tx_add_range_op(struct benchmark *bench, struct operation_info *info)
 {
-	struct obj_tx_bench *obj_bench =
-		(struct obj_tx_bench *)pmembench_get_priv(bench);
-	struct obj_tx_worker *obj_worker =
-		(struct obj_tx_worker *)info->worker->priv;
+	auto *obj_bench = (struct obj_tx_bench *)pmembench_get_priv(bench);
+	auto *obj_worker = (struct obj_tx_worker *)info->worker->priv;
 	if (add_range_op[obj_bench->lib_op](obj_bench, info->worker,
 					    info->index) != 0)
 		return -1;
@@ -726,10 +710,8 @@ obj_tx_add_range_op(struct benchmark *bench, struct operation_info *info)
 static int
 obj_tx_op(struct benchmark *bench, struct operation_info *info)
 {
-	struct obj_tx_bench *obj_bench =
-		(struct obj_tx_bench *)pmembench_get_priv(bench);
-	struct obj_tx_worker *obj_worker =
-		(struct obj_tx_worker *)info->worker->priv;
+	auto *obj_bench = (struct obj_tx_bench *)pmembench_get_priv(bench);
+	auto *obj_worker = (struct obj_tx_worker *)info->worker->priv;
 	int ret = nestings[obj_bench->nesting_mode](obj_bench, info->worker,
 						    info->index);
 	obj_worker->tx_level = 0;
@@ -744,11 +726,10 @@ static int
 obj_tx_init_worker(struct benchmark *bench, struct benchmark_args *args,
 		   struct worker_info *worker)
 {
-	struct obj_tx_bench *obj_bench =
-		(struct obj_tx_bench *)pmembench_get_priv(bench);
-	struct obj_tx_worker *obj_worker =
+	auto *obj_bench = (struct obj_tx_bench *)pmembench_get_priv(bench);
+	auto *obj_worker =
 		(struct obj_tx_worker *)calloc(1, sizeof(struct obj_tx_worker));
-	if (obj_worker == NULL) {
+	if (obj_worker == nullptr) {
 		perror("calloc");
 		return -1;
 	}
@@ -761,7 +742,7 @@ obj_tx_init_worker(struct benchmark *bench, struct benchmark_args *args,
 	else
 		obj_worker->items =
 			(char **)calloc(obj_bench->n_objs, sizeof(char *));
-	if (obj_worker->oids == NULL && obj_worker->items == NULL) {
+	if (obj_worker->oids == nullptr && obj_worker->items == nullptr) {
 		free(obj_worker);
 		perror("calloc");
 		return -1;
@@ -783,9 +764,8 @@ obj_tx_init_worker_alloc_obj(struct benchmark *bench,
 	if (obj_tx_init_worker(bench, args, worker) != 0)
 		return -1;
 
-	struct obj_tx_bench *obj_bench =
-		(struct obj_tx_bench *)pmembench_get_priv(bench);
-	struct obj_tx_worker *obj_worker = (struct obj_tx_worker *)worker->priv;
+	auto *obj_bench = (struct obj_tx_bench *)pmembench_get_priv(bench);
+	auto *obj_worker = (struct obj_tx_worker *)worker->priv;
 	for (i = 0; i < obj_bench->n_objs; i++) {
 		if (alloc_op[obj_bench->lib_mode](obj_bench, worker, i) != 0)
 			goto out;
@@ -809,9 +789,8 @@ static void
 obj_tx_exit_worker(struct benchmark *bench, struct benchmark_args *args,
 		   struct worker_info *worker)
 {
-	struct obj_tx_bench *obj_bench =
-		(struct obj_tx_bench *)pmembench_get_priv(bench);
-	struct obj_tx_worker *obj_worker = (struct obj_tx_worker *)worker->priv;
+	auto *obj_bench = (struct obj_tx_bench *)pmembench_get_priv(bench);
+	auto *obj_worker = (struct obj_tx_worker *)worker->priv;
 	for (unsigned i = 0; i < obj_bench->n_objs; i++)
 		free_op[obj_bench->lib_op_free](obj_bench, worker, i);
 
@@ -829,15 +808,14 @@ obj_tx_exit_worker(struct benchmark *bench, struct benchmark_args *args,
 static int
 obj_tx_add_range_init(struct benchmark *bench, struct benchmark_args *args)
 {
-	struct obj_tx_args *obj_args = (struct obj_tx_args *)args->opts;
+	auto *obj_args = (struct obj_tx_args *)args->opts;
 	obj_args->parse_mode = PARSE_OP_MODE_ADD_RANGE;
 	if (args->n_ops_per_thread > MAX_OPS)
 		args->n_ops_per_thread = MAX_OPS;
 	if (obj_tx_init(bench, args) != 0)
 		return -1;
 
-	struct obj_tx_bench *obj_bench =
-		(struct obj_tx_bench *)pmembench_get_priv(bench);
+	auto *obj_bench = (struct obj_tx_bench *)pmembench_get_priv(bench);
 
 	obj_bench->n_oid = diff_num;
 	if (obj_bench->op_mode < OP_MODE_ALL_OBJ) {
@@ -869,8 +847,7 @@ obj_tx_free_init(struct benchmark *bench, struct benchmark_args *args)
 	if (obj_tx_init(bench, args) != 0)
 		return -1;
 
-	struct obj_tx_bench *obj_bench =
-		(struct obj_tx_bench *)pmembench_get_priv(bench);
+	auto *obj_bench = (struct obj_tx_bench *)pmembench_get_priv(bench);
 	obj_bench->fn_op = free_op;
 
 	/*
@@ -896,8 +873,7 @@ obj_tx_alloc_init(struct benchmark *bench, struct benchmark_args *args)
 	if (obj_tx_init(bench, args) != 0)
 		return -1;
 
-	struct obj_tx_bench *obj_bench =
-		(struct obj_tx_bench *)pmembench_get_priv(bench);
+	auto *obj_bench = (struct obj_tx_bench *)pmembench_get_priv(bench);
 	obj_bench->fn_op = alloc_op;
 
 	/*
@@ -921,12 +897,11 @@ obj_tx_realloc_init(struct benchmark *bench, struct benchmark_args *args)
 	if (obj_tx_init(bench, args) != 0)
 		return -1;
 
-	struct obj_tx_bench *obj_bench =
-		(struct obj_tx_bench *)pmembench_get_priv(bench);
+	auto *obj_bench = (struct obj_tx_bench *)pmembench_get_priv(bench);
 	obj_bench->resizes =
 		rand_values(obj_bench->obj_args->min_rsize,
 			    obj_bench->obj_args->rsize, args->n_ops_per_thread);
-	if (obj_bench->resizes == NULL) {
+	if (obj_bench->resizes == nullptr) {
 		obj_tx_exit(bench, args);
 		return -1;
 	}
@@ -942,9 +917,20 @@ obj_tx_realloc_init(struct benchmark *bench, struct benchmark_args *args)
 int
 obj_tx_init(struct benchmark *bench, struct benchmark_args *args)
 {
-	assert(bench != NULL);
-	assert(args != NULL);
-	assert(args->opts != NULL);
+	assert(bench != nullptr);
+	assert(args != nullptr);
+	assert(args->opts != nullptr);
+
+	char path[PATH_MAX];
+	if (util_safe_strcpy(path, args->fname, sizeof(path)) != 0)
+		return -1;
+
+	enum file_type type = util_file_get_type(args->fname);
+	if (type == OTHER_ERROR) {
+		fprintf(stderr, "could not check type of file %s\n",
+			args->fname);
+		return -1;
+	}
 
 	pmembench_set_priv(bench, &obj_bench);
 
@@ -953,7 +939,7 @@ obj_tx_init(struct benchmark *bench, struct benchmark_args *args)
 	obj_bench.obj_args->n_ops = args->n_ops_per_thread;
 	obj_bench.n_objs = args->n_ops_per_thread;
 
-	obj_bench.lib_op = obj_bench.obj_args->lib != NULL
+	obj_bench.lib_op = obj_bench.obj_args->lib != nullptr
 		? parse_lib_mode(obj_bench.obj_args->lib)
 		: LIB_MODE_OBJ_ATOMIC;
 
@@ -1007,30 +993,39 @@ obj_tx_init(struct benchmark *bench, struct benchmark_args *args)
 	if (obj_bench.type_mode == NUM_MODE_RAND) {
 		obj_bench.random_types =
 			rand_values(1, UINT32_MAX, args->n_ops_per_thread);
-		if (obj_bench.random_types == NULL)
+		if (obj_bench.random_types == nullptr)
 			return -1;
 	}
 	obj_bench.sizes = rand_values(obj_bench.obj_args->min_size,
 				      obj_bench.obj_args->obj_size,
 				      args->n_ops_per_thread);
-	if (obj_bench.sizes == NULL)
+	if (obj_bench.sizes == nullptr)
 		goto free_random_types;
 
 	if (obj_bench.lib_mode == LIB_MODE_DRAM)
 		return 0;
 
 	/* Create pmemobj pool. */
-	if (args->is_poolset) {
+	if (args->is_poolset || type == TYPE_DEVDAX) {
 		if (args->fsize < psize) {
-			fprintf(stderr, "insufficient size of poolset\n");
+			fprintf(stderr, "file size too large\n");
 			goto free_all;
 		}
 
+		psize = 0;
+	} else if (args->is_dynamic_poolset) {
+		int ret = dynamic_poolset_create(args->fname, psize);
+		if (ret == -1)
+			goto free_all;
+
+		if (util_safe_strcpy(path, POOLSET_PATH, sizeof(path)) != 0)
+			goto free_all;
+
 		psize = 0;
 	}
-	obj_bench.pop =
-		pmemobj_create(args->fname, LAYOUT_NAME, psize, args->fmode);
-	if (obj_bench.pop == NULL) {
+
+	obj_bench.pop = pmemobj_create(path, LAYOUT_NAME, psize, args->fmode);
+	if (obj_bench.pop == nullptr) {
 		perror("pmemobj_create");
 		goto free_all;
 	}
@@ -1051,8 +1046,7 @@ free_random_types:
 int
 obj_tx_exit(struct benchmark *bench, struct benchmark_args *args)
 {
-	struct obj_tx_bench *obj_bench =
-		(struct obj_tx_bench *)pmembench_get_priv(bench);
+	auto *obj_bench = (struct obj_tx_bench *)pmembench_get_priv(bench);
 	if (obj_bench->lib_mode != LIB_MODE_DRAM)
 		pmemobj_close(obj_bench->pop);
 
@@ -1069,8 +1063,7 @@ obj_tx_exit(struct benchmark *bench, struct benchmark_args *args)
 static int
 obj_tx_realloc_exit(struct benchmark *bench, struct benchmark_args *args)
 {
-	struct obj_tx_bench *obj_bench =
-		(struct obj_tx_bench *)pmembench_get_priv(bench);
+	auto *obj_bench = (struct obj_tx_bench *)pmembench_get_priv(bench);
 	free(obj_bench->resizes);
 	return obj_tx_exit(bench, args);
 }
@@ -1083,9 +1076,9 @@ static struct benchmark_info obj_tx_free;
 static struct benchmark_info obj_tx_realloc;
 static struct benchmark_info obj_tx_add_range;
 
-CONSTRUCTOR(pmemobj_tx_costructor)
+CONSTRUCTOR(pmemobj_tx_constructor)
 void
-pmemobj_tx_costructor(void)
+pmemobj_tx_constructor(void)
 {
 	obj_tx_clo[0].opt_short = 'T';
 	obj_tx_clo[0].opt_long = "type-number";
