@@ -1,34 +1,5 @@
-/*
- * Copyright 2015-2017, Intel Corporation
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *     * Redistributions of source code must retain the above copyright
- *       notice, this list of conditions and the following disclaimer.
- *
- *     * Redistributions in binary form must reproduce the above copyright
- *       notice, this list of conditions and the following disclaimer in
- *       the documentation and/or other materials provided with the
- *       distribution.
- *
- *     * Neither the name of the copyright holder nor the names of its
- *       contributors may be used to endorse or promote products derived
- *       from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+// SPDX-License-Identifier: BSD-3-Clause
+/* Copyright 2015-2019, Intel Corporation */
 /*
  * scenario.cpp -- scenario module definitions
  */
@@ -78,7 +49,7 @@ scenario_alloc(const char *name, const char *bench)
 	struct scenario *s = (struct scenario *)malloc(sizeof(*s));
 	assert(s != nullptr);
 
-	TAILQ_INIT(&s->head);
+	PMDK_TAILQ_INIT(&s->head);
 	s->name = strdup(name);
 	assert(s->name != nullptr);
 
@@ -98,9 +69,9 @@ scenario_free(struct scenario *s)
 {
 	assert(s != nullptr);
 
-	while (!TAILQ_EMPTY(&s->head)) {
-		struct kv *kv = TAILQ_FIRST(&s->head);
-		TAILQ_REMOVE(&s->head, kv, next);
+	while (!PMDK_TAILQ_EMPTY(&s->head)) {
+		struct kv *kv = PMDK_TAILQ_FIRST(&s->head);
+		PMDK_TAILQ_REMOVE(&s->head, kv, next);
 		kv_free(kv);
 	}
 
@@ -130,7 +101,7 @@ scenarios_alloc(void)
 		(struct scenarios *)malloc(sizeof(*scenarios));
 	assert(nullptr != scenarios);
 
-	TAILQ_INIT(&scenarios->head);
+	PMDK_TAILQ_INIT(&scenarios->head);
 
 	return scenarios;
 }
@@ -142,9 +113,9 @@ void
 scenarios_free(struct scenarios *scenarios)
 {
 	assert(scenarios != nullptr);
-	while (!TAILQ_EMPTY(&scenarios->head)) {
-		struct scenario *sce = TAILQ_FIRST(&scenarios->head);
-		TAILQ_REMOVE(&scenarios->head, sce, next);
+	while (!PMDK_TAILQ_EMPTY(&scenarios->head)) {
+		struct scenario *sce = PMDK_TAILQ_FIRST(&scenarios->head);
+		PMDK_TAILQ_REMOVE(&scenarios->head, sce, next);
 		scenario_free(sce);
 	}
 
@@ -202,7 +173,7 @@ clone_scenario(struct scenario *src_scenario)
 		struct kv *new_kv = kv_alloc(src_kv->key, src_kv->value);
 		assert(new_kv != nullptr);
 
-		TAILQ_INSERT_TAIL(&new_scenario->head, new_kv, next);
+		PMDK_TAILQ_INSERT_TAIL(&new_scenario->head, new_kv, next);
 	}
 
 	return new_scenario;
